clear all
cd C:\Users\okubo\Documents/
import excel "MS20-051_all_dataset.xlsx", sheet("data") firstrow clear

*******************
**variables construction
*******************
*survival dummy: "T14"="Taisho Year 14"=Year 1925 (after quake)
gen survival=1 if Firm_ID_T14!=.
replace survival=0 if survival==.

*Dummy for banks located in Yokohama
gen yokohamabank=1 if ((Bank_code1<=14 & Bank_code1>=1 )| Bank_code1==24) | ((Bank_code2<=14 & Bank_code2>=1)| Bank_code2==24 ) | ((Bank_code3<=14 & Bank_code3>=1)| Bank_code3==24 )
replace yokohamabank=0 if yokohamabank==.

*Transaction Bank variables (mean of transaction banks)
sort Firm_ID
gen ln_size1922_mean=ln(size1922_mean)

*BOJ variables
*BOJ bill weighted by bank size
gen BOJ_bill_size=BOJ_bill_mean/size1922_mean

*Firm variables
*profit tax (firm size):"FSIZE"
gen ln_prof_tax=ln(prof_tax)
gen ln_prof_tax1925=ln(prof_tax_T14)
*size growth (change of profit tax from 1922 to 1925
gen d_ln_prof_tax=ln_prof_tax1925-ln_prof_tax

*Asset categorial variable based on definition. NB:reverse order (see Appendix Table A2 for category definition)
rename asset assetR
gen asset=25-assetR
drop assetR
*firm age (AGE)
gen age=year
*NB: "year" indicates "operating year" in original data
*replace missing by calculation based on founding year
replace age=1921-found_year if age==. & found_year!=.
gen ln_age=ln(age)


**************************
**JMCB estimations
***************************
**Table 7
sum survival d_ln_prof_tax ln_age asset direct_dam  total_damage   ln_prof_tax   ln_size1922_mean  bank_total_damage_meanR BOJ_bill_size   if ln_size1922_mean!=.& ln_age!=. & direct_dam!=. & ln_prof_tax!=.

**Table 8
reg survival ln_age asset direct_dam total_damage  ln_prof_tax   i.sector i.police  if ln_size1922_mean!=., robust cluster(police)
reg survival ln_age asset  direct_dam total_damage   ln_prof_tax ln_size1922_mean  bank_total_damage_meanR  i.sector i.police  if ln_size1922_mean!=., robust cluster(police)
reg survival ln_age asset  direct_dam total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax  bank_total_damage_meanR ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR i.sector i.police  if ln_size1922_mean!=., robust cluster(police)
reg survival ln_age asset direct_dam  total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax  bank_total_damage_meanR ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR BOJ_bill_size  c.direct_dam#c.BOJ_bill_size c.ln_prof_tax#c.BOJ_bill_size c.direct_dam#c.ln_prof_tax#c.BOJ_bill_size i.sector i.police if ln_size1922_mean!=. , robust cluster(police)

** Table 9
reg d_ln_prof_tax ln_age asset direct_dam total_damage  ln_prof_tax   i.sector i.police  if ln_size1922_mean!=., robust cluster(police)
reg d_ln_prof_tax ln_age asset  direct_dam total_damage   ln_prof_tax ln_size1922_mean  bank_total_damage_meanR  i.sector i.police  if ln_size1922_mean!=., robust cluster(police)
reg d_ln_prof_tax ln_age asset  direct_dam total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax   bank_total_damage_meanR  ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR i.sector i.police  if ln_size1922_mean!=., robust cluster(police)
reg d_ln_prof_tax ln_age asset direct_dam  total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax   bank_total_damage_meanR  ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR BOJ_bill_size  c.direct_dam#c.BOJ_bill_size c.ln_prof_tax#c.BOJ_bill_size c.direct_dam#c.ln_prof_tax#c.BOJ_bill_size i.sector i.police if ln_size1922_mean!=. , robust cluster(police)

**Tab 10
reg survival ln_age asset direct_dam  total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax   bank_total_damage_meanR  ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR BOJ_bill_size  c.direct_dam#c.BOJ_bill_size c.ln_prof_tax#c.BOJ_bill_size c.direct_dam#c.ln_prof_tax#c.BOJ_bill_size i.sector i.police if ln_size1922_mean!=. & Bank_code2==., robust cluster(police)
reg d_ln_prof_tax ln_age asset direct_dam  total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax  bank_total_damage_meanR  ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR BOJ_bill_size  c.direct_dam#c.BOJ_bill_size c.ln_prof_tax#c.BOJ_bill_size c.direct_dam#c.ln_prof_tax#c.BOJ_bill_size i.sector i.police if ln_size1922_mean!=. &  Bank_code2==., robust cluster(police)

**Tab 11
reg survival ln_age asset direct_dam  total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax  bank_total_damage_meanR  ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR BOJ_bill_size  c.direct_dam#c.BOJ_bill_size c.ln_prof_tax#c.BOJ_bill_size c.direct_dam#c.ln_prof_tax#c.BOJ_bill_size i.sector i.police if ln_size1922_mean!=.  & yokohamabank==1, robust cluster(police)
reg d_ln_prof_tax ln_age asset direct_dam  total_damage   ln_prof_tax c.direct_dam#c.ln_prof_tax c.total_damage#c.ln_prof_tax  bank_total_damage_meanR  ln_size1922_mean c.ln_size1922_mean#c.bank_total_damage_meanR  c.ln_size1922_mean#c.bank_total_damage_meanR BOJ_bill_size  c.direct_dam#c.BOJ_bill_size c.ln_prof_tax#c.BOJ_bill_size c.direct_dam#c.ln_prof_tax#c.BOJ_bill_size i.sector i.police if ln_size1922_mean!=. & yokohamabank==1, robust cluster(police)

**Fig 4
twoway scatter ln_size1922_mean ln_prof_tax, ytitle(bank size) xtitle(firm size)

